@@ -26,8 +26,6 @@
 
    Contains building blocks for creating user profiles."""
 
-# FIXME: Needs documentation.
-
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
@@ -46,7 +44,8 @@ from lck.django.choices import Country, Gender
 from lck.django.common.templatetags.thumbnail import thumbnail
 
 PROXIED_FIELDS = (set([field.name for field in User._meta.fields]) |
-                  set(['get_full_name']))
+                  set(['check_password', 'get_full_name', 'has_perm',
+                       'has_perms', 'set_password']))
 
 TZ_CHOICES = [(float(x[0]), x[1]) for x in (
     (-12, '-12'), (-11, '-11'), (-10, '-10'), (-9.5, '-09.5'), (-9, '-09'),
@@ -63,6 +62,14 @@ AVATAR_ATTR_REGEX = re.compile(r"^avatar_([whms])(\d+)$")
 
 
 class BasicInfo(db.Model):
+    """Describes a basic user profile that links through a one-to-one field
+    to ``django.contrib.auth.models.User``. Provides fields to store nicks,
+    birth dates, genders, countries of origin, cities and time zones.
+
+    This model is also a transparent proxy to the User object enabling most
+    of the functionality that would require explicitly getting the user model.
+    This enables for enhanced duck typing in scenarios where user objects
+    are expected."""
     user = db.OneToOneField(User)
     nick = db.CharField(verbose_name=_("visible nick"), blank=True, default='',
         max_length=30, help_text=_("Fill this field if you wish to change "
@@ -93,28 +100,39 @@ class BasicInfo(db.Model):
         return super(BasicInfo, self).__getattr__(name)
 
     def age(self):
+        """age() -> numeric_age"""
         if not self.birth_date:
             return '?'
         else:
             return int((date.today() - self.birth_date).days / 365.25)
 
     def is_male(self):
+        """True if the gender is male."""
         return self.gender == Gender.male.id
 
     def is_female(self):
+        """True if the gender is female."""
         return self.gender == Gender.female.id
 
     def has_gender(self):
+        """True if the gender is set."""
         return self.is_male() or self.is_female()
 
     def get_country_display_english(self):
+        """Displays the country of origin in its English form. This is useful
+        for distionary lookups."""
         return Country.RawFromID(self.country)
 
     def get_profile(self):
         return self
 
+    @property
+    def profile(self):
+        return self
+
 
 class ActivationSupport(db.Model):
+    """Adds an ``activation_token`` field."""
     activation_token = db.CharField(verbose_name=_("activation token"),
         max_length=40, editable=False, blank=True, default='')
 
@@ -123,12 +141,33 @@ class ActivationSupport(db.Model):
 
 
 class AvatarSupport(db.Model):
-    """When inheriting, create a new `avatar` field like this::
+    """Enables getting the user's gravatar by using the ``model.avatar_{size}``
+    attribute notation. Works in both code and templates.
 
-         avatar = AvatarSupport.avatar_field(upload_to='upload_directory')
+    Possible values for `size`:
 
-       To have gravatar fallback, specify `GravatarSupport` **after**
-       `AvatarSupport` in your model inheritance list.
+    * h{height} - scale to match the height given. Example: "h100" scales to
+                  100px in height. Width is scaled proportionally, may exceed
+                  100px.
+
+    * w{width} - scale to match the width given. Example: "w312" scales to
+                 312px in width. Height is scaled proportionally, may exceed
+                 312px.
+
+    * m{max_size} - scale to match the greater dimension to the value given.
+                    Example: "m50" would scale an 80x50 image to 50x31, and
+                    an 40x120 image to 17x50.
+
+    * s{max_size} - cuts a square from the image and scales it to the value
+                    given. Example: "s48" would scale a 50x80 image to 48x48
+                    based on the top 50x50 square.
+
+    When inheriting, create a new `avatar` field like this::
+
+        avatar = AvatarSupport.avatar_field(upload_to='upload_directory')
+
+    To have gravatar fallback, specify `GravatarSupport` **after**
+    `AvatarSupport` in your model inheritance list.
     """
     avatar_height = db.PositiveIntegerField(verbose_name=_("height"),
         default=None, blank=True, null=True, editable=False)
@@ -150,6 +189,12 @@ class AvatarSupport(db.Model):
 
 
 class GravatarSupport(db.Model):
+    """Enables getting the user's gravatar by using the ``model.avatar_{size}``
+    attribute notation. Works in both code and templates.
+
+    Possible values for `size` are the same as in ``AvatarSupport`` but the
+    modifier is always treated as "s".
+    """
     def get_gravatar(self, size):
         email = self.email if hasattr(self, 'email') else self.user.email
         return "http://www.gravatar.com/avatar/%s.jpg?d=identicon&s=%d" % (
